@@ -2,7 +2,7 @@ package Shipwright;
 
 use warnings;
 use strict;
-use version; our $VERSION = qv('2.4.30');
+use version; our $VERSION = qv('2.4.31');
 
 use base qw/Shipwright::Base/;
 
@@ -14,10 +14,10 @@ use Shipwright::Util;
 # strawberry perl's build make is 'dmake'
 use File::Which 'which';
 $ENV{SHIPWRIGHT_MAKE} ||= which('make') || which('dmake') || which( 'nmake' ) || 'make';
-$ENV{SHIPWRIGHT_SVK} ||= which 'svk';
-$ENV{SHIPWRIGHT_SVN} ||= which 'svn';
-$ENV{SHIPWRIGHT_GIT} ||= which 'git';
-$ENV{SHIPWRIGHT_DZIL} ||= which 'dzil';
+$ENV{SHIPWRIGHT_SVK}  ||= which('svk')  || 'svk';
+$ENV{SHIPWRIGHT_SVN}  ||= which('svn')  || 'svn';
+$ENV{SHIPWRIGHT_GIT}  ||= which('git')  || 'git';
+$ENV{SHIPWRIGHT_DZIL} ||= which('dzil') || 'dzil';
 $ENV{SHIPWRIGHT_LWP_TIMEOUT} ||= 1200;
 
 $ENV{PERL_MM_USE_DEFAULT} = 1; # always true
@@ -226,7 +226,7 @@ sunnavy  C<< <sunnavy@bestpractical.com> >>
 
 =head1 LICENCE AND COPYRIGHT
 
-Shipwright is Copyright 2007-2011 Best Practical Solutions, LLC.
+Shipwright is Copyright 2007-2012 Best Practical Solutions, LLC.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
